@@ -1,7 +1,7 @@
 #!/usr/bin/env perl
 package Gentoo::App::Pram;
 
-our $VERSION = '0.100000';
+our $VERSION = '0.100100';
 
 use warnings;
 use strict;
@@ -119,9 +119,7 @@ sub fetch_patch {
     my $status = $response->{status};
     
     $status != 200 and die "\n" . E_ERROR . qq#! Unreachable URL! Got HTTP status $status!\n#;
-    
     my $patch = $response->{content};
-    chomp $patch;
 
     print E_OK . "!\n";
     
@@ -198,7 +196,7 @@ sub apply_patch {
     if ($answer =~ /^[Yy]$/) {
         $git_command = "$git_command $patch_location";
         print E_YES . "!\n";
-        print "Launching '$git_command' ... ";
+        print "Launching '$git_command' ... \n";
         $exit = system join ' ', $git_command;
         $exit eq 0 || die E_ERROR . qq#! Error when launching '$git_command': $!!\n#;
         print E_OK . "!\n";
@@ -223,8 +221,8 @@ Gentoo::App::Pram - Library to fetch a GitHub Pull Request as an am-like patch.
 
 The purpose of this module is to fetch Pull Requests from GitHub's CDN as
 am-like patches in order to facilitate the merging and closing of Pull
-Requests. This module also takes care of adding "Closes:" and "Bug:" which are
-Gentoo-specific. See GLEP 0066.
+Requests. This module also takes care of adding "Closes:" and "Bug:" headers to
+patches when necessary. See GLEP 0066.
 
 =head1 FUNCTIONS
 
@@ -238,13 +236,16 @@ Fetch patch from $patch_url. Return patch as a string.
 
 Modify the patch headers. This function only modifies the headers of the first
 commit. Namely:
-* Add a "Closes: https://github.com/XXX" header. Check first if it wasn't
-added already. This header is parsed by the Github bot upon merge. The bot
-then automatically closes the pull request. See
+
+* Add a "Closes: https://github.com/XXX" header. Check first if it wasn't added
+already by the contributor. This header is parsed by the Github bot upon merge.
+The bot then automatically closes the pull request. See
 https://help.github.com/articles/closing-issues-using-keywords for more info.
+
 * Add a "Bug: https://bugs.gentoo.org/XXX" header when the `--bug XXX` option
 is given. This header is parsed by the Gentoo Bugzilla bot upon merge. The bot
 then writes a message in the bug report. See GLEP 0066 for more info.
+
 * Add a "Closes: https://bugs.gentoo.org/XXX" header when the `--closes XXX`
 option is given. This header is parsed by the Gentoo Bugzilla bot upon merge.
 The bot then automatically closes the bug report. See GLEP 0066 for more info.
@@ -258,7 +259,7 @@ functions also shows $patch in $editor for a final review.
 
 =head1 VERSION
 
-version 0.100
+version 0.100100
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -270,6 +271,7 @@ the same terms as the Perl 5 programming language system itself.
 =head1 AUTHOR
 
 Patrice Clement <monsieurp@gentoo.org>
+
 Kent Fredric <kentnl@gentoo.org>
 
 =cut
